@@ -21,7 +21,7 @@ _SPOT = "spot"
 _FUTURE = "future"
 _OPTION = "option"
 _LINEARSWAP = "linear-swap"
-ALL_TYPES = ["spot", "swap", "future", "option", "", "linear-swap"]
+ALL_TYPES = ["spot", "swap", "future", "option", "linear-swap"]
 ALL_DATA_TYPES = ['klines', 'trades']
 ALL_PERIODS = ['1min', '5min', '15min', '30min', '60min', '4hour', '1day']
 ALL_FREQ = ["daily"]
@@ -330,6 +330,7 @@ def load_daily_all(period='1min',
 
 def load_symbol_all(symbol='SHIBUSDT',
                     period='1min',
+                    _type=ALL_TYPES[0],
                     data_type=ALL_DATA_TYPES[0],
                     start_date=datetime(2021, 5, 1),
                     end_date=datetime(2021, 5, 23),
@@ -341,6 +342,7 @@ def load_symbol_all(symbol='SHIBUSDT',
                               all_periods=[period],
                               start_date=start_date,
                               end_date=end_date,
+                              _type=_type,
                               download_dir=download_dir2)
     history.download_klines()
     file_path = os.path.join(download_dir, f'{history.data_type}_{history.type}_{period}-{symbol}.csv')
@@ -356,7 +358,7 @@ def load_symbol_all(symbol='SHIBUSDT',
 
 def load_symbol_all_to_db(symbol='SHIBUSDT',
                           start_date=datetime(2021, 5, 1),
-                          end_date=datetime(2021, 5, 3) ):
+                          end_date=datetime(2021, 5, 3)):
     history = SymbolHistory(symbol=symbol)
     history.run(start_date=start_date, end_date=end_date)
     return history.db_path
